# Permission

The permission the user has in relation to the service.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The permission the user has in relation to the service. | defaults to "full",  must be one of ["full", "read_only", "purge_select", "purge_all", ]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


